==> pyJoules-0.4.0.tar.gz: pyJoules-0.4.0/pyJoules/exception.py <==
# MIT License
# Copyright (c) 2019, INRIA
# Copyright (c) 2019, University of Lille
# All rights reserved.
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.


class PyJoulesException(Exception):
    """
    PyJoules exceptions parent class
    """


class NoSuchDomainError(PyJoulesException):
    """
    Exception raised when a user ask to monitor a domain that is not available on the given device
    """

    def __init__(self, domain_name: str):
        """
        :param domain_name: the domain name that is not available on this device
        """
        PyJoulesException.__init__(self)
        #: the domain name that is not available on this device
        self.domain_name = domain_name


class NoSuchEnergyDeviceError(PyJoulesException):
    """
    Exception raised when a EnergyDevice that does not exist on the current machine is created
    """

==> pyJoules-0.5.0.tar.gz: pyJoules-0.5.0/pyJoules/exception.py <==
# MIT License
# Copyright (c) 2019, INRIA
# Copyright (c) 2019, University of Lille
# All rights reserved.
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.


class PyJoulesException(Exception):
    """
    PyJoules exceptions parent class
    """


class NoSuchDomainError(PyJoulesException):
    """
    Exception raised when a user ask to monitor a domain that is not available on the given device
    """

    def __init__(self, domain_name: str):
        """
        :param domain_name: the domain name that is not available on this device
        """
        PyJoulesException.__init__(self)
        #: the domain name that is not available on this device
        self.domain_name = domain_name


class NoSuchDeviceError(PyJoulesException):
    """
    Exception raised when a Device that does not exist on the current machine is created
    """
